//-*-c++-*-
/**
 Author: David Auber
 Email : auber@labri.fr
 Last modification : 20/08/2001
 This program is free software; you can redistribute it and/or modify  *
 it under the terms of the GNU General Public License as published by  
 the Free Software Foundation; either version 2 of the License, or     
 (at your option) any later version.
*/

#ifndef TULIP_SIZES_H
#define TULIP_SIZES_H

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "Types.h"
#include "Property.h"
class PropertyContext;
class SizesProxy;

/**
 * \defgroup plugins
 */ 
/*@{*/
/// Interface for sizes plug-ins
class TLP_SCOPE Sizes:public Property< SizeType , SizeType >
{ 
  ///
  friend class SizesProxy;
public:
  SizesProxy *sizesProxy;
protected:
  ///
  Sizes (const PropertyContext  &context);
  ///
  virtual ~Sizes(){}
};
/*@}*/
#endif









